@@ -36,7 +36,9 @@ class LogstashHandler(DatagramHandler):
                 'logger': record.name,
             },
             '@message': record.getMessage(),
-            '@source': host,
+            '@source': self.format_source(host, record.pathname),
+            '@source_host': host,
+            '@source_path': record.pathname,
             '@tags': [],
             '@timestamp': self.format_timestamp(record.created),
             '@type': self.message_type,
@@ -48,7 +50,6 @@ class LogstashHandler(DatagramHandler):
 
         if add_debug_info:
             message_dict['@fields']['lineno'] = record.lineno
-            message_dict['@fields']['pathname'] = record.pathname
             message_dict['@fields']['process'] = record.process
             message_dict['@fields']['threadName'] = record.threadName
             # funName was added in 2.5
@@ -84,4 +85,7 @@ class LogstashHandler(DatagramHandler):
         return ''.join(traceback.format_exception(*exc_info)) if exc_info else ''
 
     def format_timestamp(self, time):
-        return datetime.utcfromtimestamp(time).isoformat()
\ No newline at end of file
+        return datetime.utcfromtimestamp(time).isoformat()
+
+    def format_source(self, host, path):
+        return "%s://%s/%s" % (self.message_type, host, path)
